@@ -5,6 +5,7 @@
 
 from pathlib import Path
 import re
+import sys
 import textwrap
 
 import pytest
@@ -134,6 +135,115 @@ def test_parser_schema_violation():
         """,
     ]
 
+    # The validator reports a different error based on the python version, so
+    # we need to provide two copies for this to work.
+    if sys.version_info < (3, 7):
+        expected_errors.append(
+            """
+            ```
+            gleantest.event:
+              event_too_many_extras:
+                extra_keys:
+                  key_1:
+                    description: Sample extra key
+                  key_2:
+                    description: Sample extra key
+                  key_3:
+                    description: Sample extra key
+                  key_4:
+                    description: Sample extra key
+                  key_5:
+                    description: Sample extra key
+                  key_6:
+                    description: Sample extra key
+                  key_7:
+                    description: Sample extra key
+                  key_8:
+                    description: Sample extra key
+                  key_9:
+                    description: Sample extra key
+                  key_10:
+                    description: Sample extra key
+                  key_11:
+                    description: Sample extra key
+            ```
+
+            OrderedDict([('key_1', OrderedDict([('description', 'Sample extra
+            key')])), ('key_2', OrderedDict([('description', 'Sample extra
+            key')])), ('key_3', OrderedDict([('description', 'Sample extra
+            key')])), ('key_4', OrderedDict([('description', 'Sample extra
+            key')])), ('key_5', OrderedDict([('description', 'Sample extra
+            key')])), ('key_6', OrderedDict([('description', 'Sample extra
+            key')])), ('key_7', OrderedDict([('description', 'Sample extra
+            key')])), ('key_8', OrderedDict([('description', 'Sample extra
+            key')])), ('key_9', OrderedDict([('description', 'Sample extra
+            key')])), ('key_10', OrderedDict([('description', 'Sample extra
+            key')])), ('key_11', OrderedDict([('description', 'Sample extra
+            key')]))]) has too many properties
+
+            Documentation for this node:
+                The acceptable keys on the "extra" object sent with events. This is an
+                object mapping the key to an object containing metadata about the key.
+                A maximum of 10 extra keys is allowed.
+                This metadata object has the following keys:
+
+                  - `description`: **Required.** A description of the key.
+
+                Valid when `type`_ is `event`.
+            """
+        )
+    else:
+        expected_errors.append(
+            """
+            ```
+            gleantest.event:
+              event_too_many_extras:
+                extra_keys:
+                  key_1:
+                    description: Sample extra key
+                  key_10:
+                    description: Sample extra key
+                  key_11:
+                    description: Sample extra key
+                  key_2:
+                    description: Sample extra key
+                  key_3:
+                    description: Sample extra key
+                  key_4:
+                    description: Sample extra key
+                  key_5:
+                    description: Sample extra key
+                  key_6:
+                    description: Sample extra key
+                  key_7:
+                    description: Sample extra key
+                  key_8:
+                    description: Sample extra key
+                  key_9:
+                    description: Sample extra key
+            ```
+
+            {'key_1': {'description': 'Sample extra key'}, 'key_2':
+            {'description': 'Sample extra key'}, 'key_3': {'description': 'Sample
+            extra key'}, 'key_4': {'description': 'Sample extra key'}, 'key_5':
+            {'description': 'Sample extra key'}, 'key_6': {'description': 'Sample
+            extra key'}, 'key_7': {'description': 'Sample extra key'}, 'key_8':
+            {'description': 'Sample extra key'}, 'key_9': {'description': 'Sample
+            extra key'}, 'key_10': {'description': 'Sample extra key'}, 'key_11':
+            {'description': 'Sample extra key'}} has too many properties
+
+            Documentation for this node:
+                The acceptable keys on the "extra" object sent with events. This is an
+                object mapping the key to an object containing metadata about the key.
+                A maximum of 10 extra keys is allowed.
+                This metadata object has the following keys:
+
+                  - `description`: **Required.** A description of the key.
+
+                Valid when `type`_ is `event`.
+            """
+        )
+
     expected_errors = set(
         re.sub(r"\s", "", _utils.indent(textwrap.dedent(x)).strip())
         for x in expected_errors
@@ -503,3 +613,11 @@ def test_do_not_disable_expired():
 
     metrics = all_metrics.value
     assert metrics["category"]["metric"].disabled is False
+
+
+def test_send_in_pings_restrictions():
+    """Test that invalid ping names are disallowed in `send_in_pings`."""
+    all_metrics = parser.parse_objects(ROOT / "data" / "invalid-ping-names.yaml")
+    errors = list(all_metrics)
+    assert len(errors) == 1
+    assert "'invalid_ping_name' does not match" in errors[0]
